@@ -293,7 +293,7 @@ def main_prg():
         else Timestamp(args.startTime)
     )
     # localising the timezone
-    startTime = starTime.tz_localize(OS_TZ)
+    startTime = startTime.tz_localize(OS_TZ)
 
     # To avoid empty request we stop one unit befor the present date.
     endTime = (
@@ -318,7 +318,7 @@ def main_prg():
         "endTime": endTime,
         "fout": f"{args.fout}{args.symbol}-{args.binSize}-{endTime}",
         "pause": args.pause,
-        "startTime": starTime,
+        "startTime": startTime,
     }
 
     # use live or test ids
